@@ -5,8 +5,8 @@ use GitHub::MergeVelocity;
 
 my $mv = GitHub::MergeVelocity->new(
     url => [
-        'https://github.com/neilbowers/PAUSE-Permissions',
-        'https://github.com/oalders/html-restrict',
+        'neilbowers/PAUSE-Permissions',
+        'https://github.com/oalders/html-restrict/issues',
     ]
 );
 
