@@ -1,5 +1,5 @@
 package GitHub::MergeVelocity;
-$GitHub::MergeVelocity::VERSION = '0.000006';
+$GitHub::MergeVelocity::VERSION = '0.000007';
 use strict;
 use warnings;
 
@@ -7,7 +7,7 @@ use CLDR::Number::Format::Percent     ();
 use File::HomeDir                     ();
 use GitHub::MergeVelocity::Repository ();
 use Module::Runtime qw( require_module use_module );
-use Moo;
+use Moo 1.007000;
 use MooX::HandlesVia;
 use MooX::Options;
 use MooX::StrictConstructor;
@@ -216,7 +216,7 @@ GitHub::MergeVelocity - Determine how quickly your pull request might get merged
 
 =head1 VERSION
 
-version 0.000006
+version 0.000007
 
 =head1 SYNOPSIS
 
